Introduction — optTune 0.1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- optTune 0.1.0 documentation »

# Introduction

The optimization tuning (optTune) package contains various tuning algorithms, many of which are design for tuning an optimization algorithm under multiple objective function evaluation OFE budgets.

Contents:

- tMOPSO
- Speeding things up

OptTune is research code, and is intended to be used in a hands on manner. Feel free to browse the source code, and make modifications subject to the GNU General Public License v3.0

Bugs can be reported at the optTune project pages, https://code.google.com/p/opt-tune-python-package/

### Navigation

- index
- modules |
- next |
- previous |
- optTune 0.1.0 documentation »